@@ -2,7 +2,7 @@ import pybullet as pyb
 import pybullet_data
 
 
-def cubes_and_2dof(client_id):
+def cube_and_ground(client_id):
     pyb.setAdditionalSearchPath(pybullet_data.getDataPath(), physicsClientId=client_id)
 
     # ground plane
@@ -48,3 +48,39 @@ def exclude_behind_left_workspace(client_id):
         "cube2": cube2_id,
     }
     return bodies
+
+
+def exclude_ground(client_id):
+    pyb.setAdditionalSearchPath(pybullet_data.getDataPath(), physicsClientId=client_id)
+
+    # ground plane
+    ground_id = pyb.loadURDF(
+        "plane.urdf",
+        [0, 0, 0],
+        useFixedBase=True,
+        physicsClientId=client_id,
+    )
+
+    # store body indices in a dict with more convenient key names
+    bodies = {
+        "ground": ground_id,
+    }
+    return bodies
+
+
+def exclude_ground_minus_2m(client_id):
+    pyb.setAdditionalSearchPath(pybullet_data.getDataPath(), physicsClientId=client_id)
+
+    # ground plane
+    ground_id = pyb.loadURDF(
+        "plane.urdf",
+        [0, 0, -2],
+        useFixedBase=True,
+        physicsClientId=client_id,
+    )
+
+    # store body indices in a dict with more convenient key names
+    bodies = {
+        "ground": ground_id,
+    }
+    return bodies
